%define debug_package %{nil}

Name:           zfs-auto-snapshot
Version:        1.2.4
Release:        1%{?dist}
Summary:        Implementation of a snapshotting service for ZFS

License:        GPL2
URL:            https://github.com/zfsonlinux/zfs-auto-snapshot
Source0:        %{url}/archive/upstream/%{version}.tar.gz
Patch:         0001-prefix_label_order.patch
BuildRequires:  systemd-rpm-macros
Requires:       systemd bash

%description
ZFS Automatic Snapshot Service for Linux

%prep
%setup  -n %{name}-upstream-%{version}
%patch -p 1

%build
mkdir -p "../systemd"
cd "../systemd"

### "Label|NumberOfKeptSnapshots|systemd-timer-spec" of snapshots,
### eg. timer and service files, being created adjust/extend if required

declare -a arr=(
  "frequent|4|*:0/15"
  "hourly|24|hourly"
  "daily|31|daily"
  "weekly|8|weekly"
  "monthly|12|monthly")

for i in "${arr[@]}"
do
  _label="$(echo $i | cut -d'|' -f1)"
  _keep="$(echo $i | cut -d'|' -f2)"
  _OnCalendarSpec="$(echo $i | cut -d'|' -f3)"
  _snapprefix="--prefix=znap"
  cat > zfs-auto-snapshot-${_label}.service <<EOF
[Unit]
Description=ZFS $_label snapshot service

[Service]
ExecStart=%{_bindir}/zfs-auto-snapshot --skip-scrub $_snapprefix --label=$_label --keep=$_keep //
EOF

  # write timer files
  cat > zfs-auto-snapshot-${_label}.timer <<EOF
# See systemd.timers and systemd.time manpages for details
[Unit]
Description=ZFS $_label snapshot timer

[Timer]
OnCalendar=$_OnCalendarSpec
Persistent=true

[Install]
WantedBy=timers.target
EOF
done


%install
%{__install} -d "%{buildroot}%{_bindir}"
%{__install} -d "%{buildroot}%{_unitdir}"
%{__install} -d "%{buildroot}%{_mandir}/man8"
%{__install} -m 755 src/zfs-auto-snapshot.sh "%{buildroot}%{_bindir}/zfs-auto-snapshot"
%{__install} -m 644 src/zfs-auto-snapshot.8 "%{buildroot}%{_mandir}/man8"
%{__install} -m 644 ../systemd/* "%{buildroot}%{_unitdir}"


%files
%license COPYING
%doc README
%{_bindir}/zfs-auto-snapshot
%{_mandir}/man8/zfs-auto-snapshot.8.gz
%{_unitdir}/zfs-auto-snapshot-daily.service
%{_unitdir}/zfs-auto-snapshot-daily.timer
%{_unitdir}/zfs-auto-snapshot-frequent.service
%{_unitdir}/zfs-auto-snapshot-frequent.timer
%{_unitdir}/zfs-auto-snapshot-hourly.service
%{_unitdir}/zfs-auto-snapshot-hourly.timer
%{_unitdir}/zfs-auto-snapshot-monthly.service
%{_unitdir}/zfs-auto-snapshot-monthly.timer
%{_unitdir}/zfs-auto-snapshot-weekly.service
%{_unitdir}/zfs-auto-snapshot-weekly.timer

%changelog
* Sun Jul 10 2022 Thomas Büttner <thomas@vergesslicher.tech>
-
